#
# spec file for package libyui-qt-graph
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libyui-qt-graph
Version:        2.46.3
Release:        lp152.1.1
Source:         %{name}-%{version}.tar.bz2

%define so_version 11
%define bin_name %{name}%{so_version}

BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++
BuildRequires:  graphviz-devel >= 2.26.0
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  libyui-devel >= 3.9.0

%define libyui_qt_devel_version libyui-qt-devel >= 2.52.0
BuildRequires:  %{libyui_qt_devel_version}

Url:            http://github.com/libyui/
Summary:        Libyui - Qt Graph Widget
License:        LGPL-2.1-only OR LGPL-3.0-only
Group:          System/Libraries

%description
This package contains the Qt graph
component for libYUI.


%package -n %{bin_name}

Requires:       libyui%{so_version}
Supplements:    libyui-qt%{so_version}
Provides:       %{name} = %{version}

Provides:       yast2-qt-graph = 2.46.0
Obsoletes:      yast2-qt-graph < 2.46.0

Url:            http://github.com/libyui/
Summary:        Libyui - Qt Graph Widget
Group:          System/Libraries

%description -n %{bin_name}
This package contains the Qt graph
component for libYUI.



%package devel

Requires:       %{bin_name} = %{version}
Requires:       %{libyui_qt_devel_version}

Url:            http://github.com/libyui/
Summary:        Libyui-qt-graph header files
Group:          Development/Languages/C and C++

%description devel
This package contains the Qt graph
component for libYUI.


This can be used independently of YaST for generic (C++) applications.
This package has very few dependencies.


%prep
%setup -q -n %{name}-%{version}

%build

export CFLAGS="$RPM_OPT_FLAGS -DNDEBUG"
export CXXFLAGS="$RPM_OPT_FLAGS -DNDEBUG"

./bootstrap.sh %{_prefix}

mkdir build
cd build

%if %{?_with_debug:1}%{!?_with_debug:0}
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELWITHDEBINFO
%else
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELEASE
%endif

make %{?jobs:-j%jobs}

%install
cd build
make install DESTDIR="$RPM_BUILD_ROOT"
install -m0755 -d $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/
install -m0755 -d $RPM_BUILD_ROOT/%{_libdir}/yui
install -m0644 ../COPYING* $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/

%clean
rm -rf "$RPM_BUILD_ROOT"

%post -n %{bin_name} -p /sbin/ldconfig

%postun -n %{bin_name} -p /sbin/ldconfig

%files -n %{bin_name}
%defattr(-,root,root)
%dir %{_libdir}/yui
%{_libdir}/yui/lib*.so.*
%doc %dir %{_docdir}/%{bin_name}
%license %{_docdir}/%{bin_name}/COPYING*

%files devel
%defattr(-,root,root)
%dir %{_docdir}/%{bin_name}
%{_libdir}/yui/lib*.so
%{_prefix}/include/yui
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}
%doc %{_docdir}/%{bin_name}/examples

%changelog
* Tue May 19 2020 aschnell@suse.com
- allow to move graph by dragging mouse (bsc#1171865)
- 2.46.3
* Thu May 14 2020 aschnell@suse.com
- handle multi-line labels (bsc#1171700)
- 2.46.2
* Tue Mar 24 2020 Stefan Hundhammer <shundhammer@suse.com>
- Fixed Qt 5.15 deprecated warnings (bsc#1165118)
- 2.46.1
* Tue Dec 10 2019 Rodion Iafarov <riafarov@suse.com>
- Increase SO version to 11 (bsc#1132247)
- 2.46.0
* Mon Dec  2 2019 Martin Vidner <mvidner@suse.com>
- Do not require graphviz-devel for the doc package (bsc#1157916)
- 2.45.5
* Thu Nov 28 2019 aschnell@suse.com
- Respect backslashes (graphviz escString) in texts (bsc#1157916)
- 2.45.4
* Thu Sep 12 2019 Martin Vidner <mvidner@suse.com>
- Make scroll-up mean zoom-in (bsc#1149158)
- 2.45.3
* Tue May  7 2019 Stefan Hundhammer <shundhammer@suse.com>
- Fixed empty labels in graph elements (bsc#1130502):
  Proper replacement for obsolete QPainter::initFrom()
- 2.45.2
* Wed Apr 17 2019 Stefan Hundhammer <shundhammer@suse.com>
- Fixed obsolete warnings when building against Qt 5.13 (bsc#1130502)
- 2.45.1
* Fri Apr 12 2019 Rodion Iafarov <riafarov@suse.com>
- Bump the .so version to 10 to be compatible with the other libyui
  packages (bsc#1132247)
- 2.45.0
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Mon Jul 30 2018 lslezak@suse.cz
- Update the version to match the other packages (improvement
  for handling big disks, bsc#991090)
- 2.44.9
* Fri May 25 2018 igonzalezsosa@suse.com
- Drop qt5_use_modules (related to bsc#1091286).
- 2.44.8
* Mon May  7 2018 igonzalezsosa@suse.com
- Replace qt5_use_modules with target_link_libraries (bsc#1091286).
- 2.44.7
* Tue Aug  8 2017 mvidner@suse.com
- Adjusted to increased so version of the base library (bsc#1052217)
- 2.44.6
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Wed Sep  2 2015 aschnell@suse.com
- bumped so version to match the base library (boo#937026).
- 2.44.4
* Tue Jan 20 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (PREFIX in spec, boo#911875).
- 2.44.3
* Sat May 24 2014 bjoern.esser@gmail.com
- clarify license by adding license headers from libyui
- pull in GPLv3-license, since LGPLv3 is additional rules on top
- 2.44.2
* Tue Feb 25 2014 mvidner@suse.com
- merged git and Factory state: the patch is now upstreamed:
  0001-use-cgraph-instead-of-graph-interfaces.patch
- Ported to Qt5
- 2.44.1
* Mon Jan 13 2014 mvidner@suse.com
- use cgraph interfaces if available, to fix building with
  graphviz 2.30 (dvaleev)
  0001-use-cgraph-instead-of-graph-interfaces.patch
* Wed Jan  8 2014 mvidner@suse.com
- adjusted to libyui so version 6
- 2.43.0
* Fri Sep 27 2013 coolo@suse.com
- supplement libyui-qt (bnc#793893)
* Wed Jun 26 2013 tgoettlicher@suse.de
- fixed libgvc dependency (bnc #825751)
- Version 2.42.7
* Sat May 18 2013 bjoern.esser@gmail.com
- fix build on graphviz >= 2.30.0
  libgraph is gone / superseeded by libcgraph
- Version 2.42.6
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- introduce bootstrap.sh
- fixup COPYING*
- Version 2.42.5
* Mon May  6 2013 bjoern.esser@gmail.com
- fix build issues
- Version 2.42.4
* Mon May  6 2013 bjoern.esser@gmail.com
- Version 2.42.3
- use SONAME from libyui instead of VERSION.cmake
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Tue Apr 10 2012 aschnell@suse.de
- changed license to GPL-2.0
* Sun Mar 21 2010 coolo@novell.com
- fix compilation with latest graphviz
- 2.19.0
* Tue Jul 14 2009 aschnell@suse.de
- replaced Recommends in yast2-storage with Supplements in
  yast2-qt-graph (bnc #521545)
* Thu Mar 26 2009 aschnell@suse.de
- fixed certain colors when using styles
* Mon Mar  9 2009 aschnell@suse.de
- added support for context menus
- 2.18.4
* Tue Feb 24 2009 aschnell@suse.de
- support newlines in tooltips
* Tue Feb 17 2009 aschnell@suse.de
- various minor fixes and improvements
- 2.18.3
* Tue Jan 27 2009 aschnell@suse.de
- added simple user-interaction
- 2.18.2
* Fri Jan 23 2009 aschnell@suse.de
- improved renderer
- 2.18.1
* Thu Jan 15 2009 aschnell@suse.de
- initial version
- 2.18.0
